@@ -10,12 +10,11 @@ class CreatePayoutAccount:
         self.route = "/payoutaccount/create"
 
     def Process(self, request):
-        # Create session request
+        # Create request
         json_data = json.dumps(request)
-
-        # POST Request for sessionId
         conn = http.client.HTTPSConnection(self.endpoint)
-        headers = {'Content-type': 'application/json'}
+        headers = {"Content-type": "application/json",
+                   "Accept": "application/json"}
         # Send the request
         conn.request('POST', self.route, json_data, headers)
         response = json.loads(conn.getresponse().read().decode())
