@@ -1,5 +1,5 @@
 import http.client
-
+import json
 from payout.create_payout_account import CreatePayoutAccount
 
 
@@ -8,10 +8,11 @@ class Payout:
         self.app = app
         self.key = key
         # Get app endpoints
-        conn = http.client.HTTPSConnection("dashboard.redshepherd.com")
+        conn = http.client.HTTPSConnection("reddash.azurewebsites.net")
         route = "/app/endpoints/" + self.app
+        headers = {"Accept": "application/json"}
         # Send the request
-        conn.request('POST', route)
+        conn.request("POST", route, "", headers)
         response = json.loads(conn.getresponse().read().decode())
         # Parse and set dataEndpoints
         if "dataEndpoints" in response:
